<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Theme Customizer</source>
        <translation>Customiser le thème</translation>
    </message>
    <message>
        <source>Current theme: </source>
        <translation>Thème actuel: </translation>
    </message>
    <message>
        <source>Use custom (fast) window transitions</source>
        <translation>Utiliser les transitions (rapide) de fenêtre customisées</translation>
    </message>
    <message>
        <source>Setting up window transitions</source>
        <translation>Configurer les transitions de fenêtre</translation>
    </message>
    <message>
        <source>Export theme</source>
        <translation>Exporter le thème</translation>
    </message>
    <message>
        <source>Import theme</source>
        <translation>Importer un thème</translation>
    </message>
    <message>
        <source>Exporting theme</source>
        <translation>Exportation du thème</translation>
    </message>
    <message>
        <source>Select .tgz file to import</source>
        <translation>Séléctionner un fichier .tgz pour l&apos;importer</translation>
    </message>
    <message>
        <source>Importing theme</source>
        <translation>Importation du thème</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Restore theme files</source>
        <translation>Restaurer les fichiers du thème</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Delete saved themes</source>
        <translation>Effacer les thèmes sauvegarder</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Selected theme is currently in use!</source>
        <translation>Séléctionner le thème courrant!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>You can&apos;t delete a theme that&apos;s currently active.</source>
        <translation>Vous ne pouvez pas effacer le thème courrant.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Delete theme?</source>
        <translation>Effacer le thème ?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Are you sure you want to delete this theme?</source>
        <translation>Etes-vous sur de vouloir effacer ce thème?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Theme deleted.</source>
        <translation>Thème effacer.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Menu bar opacity</source>
        <translation>Opacité de la barre de menu</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>You must give name for the theme.</source>
        <translation>Vous devez donner un nom au thème.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Folder </source>
        <translation>Dossier </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source> already exists!</source>
        <translation> existe dèja!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Saving new theme...</source>
        <translation>Sauvegarde du nouveau thème...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Save as new theme</source>
        <translation>Créer comme un  nouveau thème</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values.</source>
        <translation>Redémarage des services, l&apos;écran va glignoter!Je vous recommande de redémarer le mobile pour recharger toutes les nouvelles valeurs.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Creating backups...</source>
        <translation>Création de la sauvegarde...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>You must give name for the preset.</source>
        <translation>Vous devez donner un nom à la présélection.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Preset saved!</source>
        <translation>Présélection sauvegarder!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Preset loaded.</source>
        <translation>Présélection chargée.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Preset deleted.</source>
        <translation>Présélection effacée.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up font family...</source>
        <translation>Application des fontes...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up font sizes...</source>
        <translation>Application de la taille...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up font colors...</source>
        <translation>Application des couleurs...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up icon theme...</source>
        <translation>Application du thème d&apos;icônes...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up snap-to-grid...</source>
        <translation>Application de la taille de la grille...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up shortcut and bookmark sizes...</source>
        <translation>Application de la taille des raccourcis et des favaoris...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Setting up widget opacities...</source>
        <translation>Application de l&apos;opacité...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Restarting services...</source>
        <translation>Redémarage des services...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Restoring files, please wait...</source>
        <translation>Restauration des fichiers, patientez svp...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Theme Customizer - restore files</source>
        <translation>Theme Customizer - Restaure les fichiers</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Do you want to restore all original theme files?</source>
        <translation>Voulez-vous restaurer tous les fichiers original du thème?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Restoring files from backup</source>
        <translation>Restauration des fichiers depuis la sauvegarde</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Reading settings...</source>
        <translation>Chargement des paramètres...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Reading settings</source>
        <translation>Chargement des paramètres</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Ok, thanks.</source>
        <translation>Ok, merci.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Overwrite color preset?</source>
        <translation>Ecraser la présélection?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Color preset with this name already exists, do you want to overwrite it?</source>
        <translation>La présélection avec ce nom existe, voulez-vous l&apos;écraser?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Delete color preset?</source>
        <translation>Effacer la présélection de couleurs?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Are you sure you want to delete this preset?</source>
        <translation>Etes-vous sur de vouloir effacer cette présélection?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Color presets</source>
        <translation>Présélections de couleur</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="0"/>
        <source>Save color preset</source>
        <translation>Enregistrer les couleurs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="120"/>
        <source>Font size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="147"/>
        <source>DEFAULT</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="152"/>
        <source>-5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="157"/>
        <source>-3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="162"/>
        <source>-1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="167"/>
        <source>+1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>+3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="177"/>
        <source>+5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="192"/>
        <source>Font colors</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="224"/>
        <source>Primary font</source>
        <translation>Première</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="242"/>
        <source>Secondary font</source>
        <translation>Deuxième</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="260"/>
        <source>Active font</source>
        <translation>Active</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="278"/>
        <source>Disabled font</source>
        <translation>Désactivée</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="360"/>
        <source>Painted font</source>
        <translation>Colorée</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button font</source>
        <translation>Bouton</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button pressed</source>
        <translation>Bouton appuyé</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="394"/>
        <source>&quot;Paint&quot; color</source>
        <translation>Couleur &quot;Paint&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="437"/>
        <source>Icon theme</source>
        <translation>Thème d&apos;icônes</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Homescreen</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="482"/>
        <source>Show app shortcut backgrounds</source>
        <translation>Voir le fond des raccourcis</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="508"/>
        <source>Snap-to-grid size</source>
        <translation>Taille de la grille</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Widget opacity</source>
        <translation>Opacité</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="560"/>
        <source>App shortcut size</source>
        <translation>Taille des raccourcis</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="575"/>
        <source>Web bookmark size</source>
        <translation>Taille des favoris</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="721"/>
        <source>Reboot</source>
        <translation>Redémarer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="736"/>
        <source>Auto-reboot after saving settings</source>
        <translation>Redémarage automatique après l&apos;application des changements</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="751"/>
        <location filename="mainwindow.cpp" line="352"/>
        <source>Apply changes</source>
        <translation>Appliquer les changements</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="771"/>
        <source>Test</source>
        <translation>Menu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="780"/>
        <source>Import fonts from folder</source>
        <translation>Importer des fontes</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="783"/>
        <source>Import all font files from MyDocs</source>
        <translation>Importer toutes les fontes depuis &quot;MyDocs&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>About</source>
        <translation>A propos de</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Change backgrounds</source>
        <translation>Changer le fond d&apos;écran</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <source>Setting up the theme, please wait...</source>
        <translation>Application des changement, patientez svp...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Abort</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Searching and importing fonts, please wait...</source>
        <translation>Recherche et importation des fontes, patientez svp...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="349"/>
        <source>Save and reboot</source>
        <translation>Sauvegarde et redémarage</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>Theme Customizer - font import</source>
        <translation>Customiser le thème</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="361"/>
        <source>Do you want to import fonts from MyDocs?</source>
        <translation>Voulez-vous importer les fontes depuis &quot;MyDocs&quot;?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="362"/>
        <source>Note: this function will only import .ttf and .otf fonts from root of MyDocs</source>
        <translation>Note: Cette fonction importe seulement les fontes .ttf et .otf depuis le dossier &quot;MyDocs&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="370"/>
        <source>Importing fonts</source>
        <translation>Importer des fontes</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="393"/>
        <source>About Theme Customizer</source>
        <translation>A propos de &quot;Theme Customizer&quot;</translation>
    </message>
</context>
<context>
    <name>backgrounds</name>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Clock</source>
        <translation>Horloge et
Alarmes</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>App Manager</source>
        <translation>Gestionnaire
d&apos;application</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Media Player</source>
        <translation>Lecteur
multimédia</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Lockscreen</source>
        <translation>Ecran de
déverrouillage</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Tap me to change</source>
        <translation>Cliquez pour changer</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Set image</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="backgrounds.ui" line="0"/>
        <source>Backgrounds</source>
        <translation>Fond d&apos;écran</translation>
    </message>
    <message>
        <location filename="backgrounds.cpp" line="0"/>
        <source>Select image</source>
        <translation>Sélectionne l&apos;image</translation>
    </message>
    <message>
        <location filename="backgrounds.cpp" line="0"/>
        <source>Processing image</source>
        <translation>Traitement de l&apos;image</translation>
    </message>
    <message>
        <location filename="backgrounds.cpp" line="0"/>
        <source>Image saved!</source>
        <translation>Image sauvegardée!</translation>
    </message>
</context>
<context>
    <name>savepreset</name>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save color preset as...</source>
        <translation>Enregistrer la présélection de couleurs sous...</translation>
    </message>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="savepreset.ui" line="0"/>
        <source>Save color preset</source>
        <translation>Enregistrer la présélection de couleurs</translation>
    </message>
</context>
<context>
    <name>managepresets</name>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Choose color preset:</source>
        <translation>Choisir la présélection de couleurs:</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Currently active colors</source>
        <translation>Couleurs actives</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Load</source>
        <translation>Charger</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Delete</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Manage color presets</source>
        <translation>Gestion des présélections de couleurs</translation>
    </message>
    <message>
        <location filename="managepresets.ui" line="0"/>
        <source>Original colors of current theme</source>
        <translation>Couleur originale du thème actuel</translation>
    </message>
</context>
<context>
    <name>savenewtheme</name>
    <message>
        <location filename="savenewtheme.ui" line="0"/>
        <source>Save theme as...</source>
        <translation>Enregistrer le thème sous...</translation>
    </message>
    <message>
        <location filename="savenewtheme.ui" line="0"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
</context>
<context>
    <name>managethemes</name>
    <message>
        <location filename="managethemes.ui" line="0"/>
        <source>Select theme:</source>
        <translation>Sélectionner le thème:</translation>
    </message>
    <message>
        <location filename="managethemes.ui" line="0"/>
        <source>Delete</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="managethemes.cpp" line="0"/>
        <source>No themes created by Theme Customizer found</source>
        <translation>Aucun thème créer avec Theme Customizer trouvé</translation>
    </message>
</context>
</TS>
